@@ -110,11 +110,14 @@ typedef struct SPICE_ATTR_PACKED SpiceSubMessageList {
 enum {
     SPICE_PLAYBACK_CAP_CELT_0_5_1,
     SPICE_PLAYBACK_CAP_VOLUME,
+    SPICE_PLAYBACK_CAP_LATENCY,
+    SPICE_PLAYBACK_CAP_OPUS,
 };
 
 enum {
     SPICE_RECORD_CAP_CELT_0_5_1,
     SPICE_RECORD_CAP_VOLUME,
+    SPICE_RECORD_CAP_OPUS,
 };
 
 enum {
@@ -129,12 +132,19 @@ enum {
     SPICE_DISPLAY_CAP_MONITORS_CONFIG,
     SPICE_DISPLAY_CAP_COMPOSITE,
     SPICE_DISPLAY_CAP_A8_SURFACE,
+    SPICE_DISPLAY_CAP_STREAM_REPORT,
 };
 
 enum {
     SPICE_INPUTS_CAP_KEY_SCANCODE,
 };
 
+enum {
+    SPICE_PORT_EVENT_OPENED,
+    SPICE_PORT_EVENT_CLOSED,
+    SPICE_PORT_EVENT_BREAK,
+};
+
 #include <spice/end-packed.h>
 
 #endif /* _H_SPICE_PROTOCOL */
